@@ -109,6 +109,7 @@ if ($do==1) {
       # https://technet.microsoft.com/en-us/library/hh831475.aspx
       # http://twiki.org/cgi-bin/view/TWiki/TWikiOnWindowsIISCygwin
       # https://www.iis.net/configreference/system.webserver/fastcgi
+      print "\n   Installing Microsoft IIS Web Server . . .\n\n";
       ($stdout,$stderr)=$handle->cmd("DISM.EXE /enable-feature /all ".
          "/online /featureName:IIS-WebServerRole /featureName:IIS-WebServer ".
          "/featureName:IIS-CommonHttpFeatures /featureName:IIS-StaticContent ".
@@ -148,6 +149,11 @@ if ($do==1) {
       $cygloc=~s/\\/\\\\/g;
       ($stdout,$stderr)=$handle->cwd($appcmd);
       ($stdout,$stderr)=$handle->cmd("pwd",'__display__');
+      my $sleep=0;
+      while (!(-e ./appcmd.exe)) {
+         sleep 2;
+         last if $sleep++>300;
+      }
       ($stdout,$stderr)=$handle->cmd("./appcmd add site /name:FullAutoAPI ".
          "/id:2 /physicalPath:$cygloc\\root /bindings:http/*:5000",
          '__display__');
